@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
- * Copyright (C) 2008, Nokia (urho.konttori@nokia.com)
+ * Copyright (C) 2006, Jamie McCracken <jamiemcc@gnome.org>
+ * Copyright (C) 2008, Nokia <ivan.frade@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -31,29 +31,12 @@ G_BEGIN_DECLS
 
 gboolean tracker_is_empty_string            (const char  *str);
 gboolean tracker_is_blank_string            (const char  *str);
-gchar *  tracker_string_replace             (const gchar *haystack,
-                                             const gchar *needle,
-                                             const gchar *replacement);
-gchar *  tracker_string_remove              (gchar       *haystack,
-                                             const gchar *needle);
 gchar *  tracker_seconds_estimate_to_string (gdouble      seconds_elapsed,
                                              gboolean     short_string,
                                              guint        items_done,
                                              guint        items_remaining);
 gchar *  tracker_seconds_to_string          (gdouble      seconds_elapsed,
                                              gboolean     short_string);
-gchar*   tracker_uri_vprintf_escaped        (const gchar *format,
-                                             va_list      args);
-gchar*   tracker_uri_printf_escaped         (const gchar *format,
-                                             ...);
-gchar *  tracker_coalesce                   (gint n_values,
-                                             ...);
-gchar *  tracker_merge                      (const gchar *delim, gint n_values,
-                                             ...);
-
-gchar *  tracker_text_normalize             (const gchar *text,
-                                             guint        max_words,
-                                             guint       *n_words);
 
 G_END_DECLS
 
