@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
- * Copyright (C) 2008-2009, Nokia
+ * Copyright (C) 2006, Jamie McCracken <jamiemcc@gnome.org>
+ * Copyright (C) 2008-2009, Nokia <ivan.frade@nokia.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -556,7 +556,7 @@ get_genre_number (const char *str, guint *genre)
 static const gchar *
 get_genre_name (guint number)
 {
-	if (number > G_N_ELEMENTS (genre_names)) {
+	if (number >= G_N_ELEMENTS (genre_names)) {
 		return NULL;
 	}
 
@@ -743,7 +743,7 @@ get_id3 (const gchar *data,
 
 	pos += 30;
 	year = g_convert (pos, 4, "UTF-8", encoding, NULL, NULL, NULL);
-	if (atoi (year) > 0) {
+	if (year && atoi (year) > 0) {
 		id3->recording_time = tracker_date_guess (year);
 	}
 	g_free (year);
@@ -960,7 +960,8 @@ id3v24_text_to_utf8 (const gchar  encoding,
 {
 	/* This byte describes the encoding
 	 * try to convert strings to UTF-8
-	 * if it fails, then forget it
+	 * if it fails, then forget it.
+	 * For UTF-16 if size odd assume invalid 00 term.
 	 */
 
 	switch (encoding) {
@@ -972,13 +973,13 @@ id3v24_text_to_utf8 (const gchar  encoding,
 		                            NULL, NULL, NULL);
 	case 0x01 :
 		return convert_to_encoding (text,
-		                            len,
+		                            len - len%2,
 		                            "UTF-8",
 		                            "UTF-16",
 		                            NULL, NULL, NULL);
 	case 0x02 :
 		return convert_to_encoding (text,
-		                            len,
+		                            len - len%2,
 		                            "UTF-8",
 		                            "UTF-16BE",
 		                            NULL, NULL, NULL);
@@ -1006,6 +1007,7 @@ id3v2_text_to_utf8 (const gchar  encoding,
 	/* This byte describes the encoding
 	 * try to convert strings to UTF-8
 	 * if it fails, then forget it
+	 * For UCS2 if size odd assume invalid 00 term.
 	 */
 
 	switch (encoding) {
@@ -1021,7 +1023,7 @@ id3v2_text_to_utf8 (const gchar  encoding,
 		/*                                "UTF-8", */
 		/*                                "UCS-2", */
 		/*                                NULL, NULL, NULL); */
-		return ucs2_to_utf8 (text, len);
+		return ucs2_to_utf8 (text, len - len%2);
 
 	default:
 		/* Bad encoding byte,
@@ -1215,6 +1217,8 @@ get_id3v24_tags (const gchar          *data,
 				g_strstrip (word);
 			}
 
+			g_debug ("Frame is %d, word is %s", frame, word);
+
 			switch (frame) {
 			case ID3V24_TALB:
 				tag->album = word;
@@ -1281,9 +1285,9 @@ get_id3v24_tags (const gchar          *data,
 				parts = g_strsplit (word, "/", 2);
 				if (parts[0]) {
 					tag->track_number = atoi (parts[0]);
-				}
-				if (parts[1]) {
-					tag->track_count = atoi (parts[1]);
+					if (parts[1]) {
+						tag->track_count = atoi (parts[1]);
+					}
 				}
 				g_strfreev (parts);
 				g_free (word);
@@ -1298,7 +1302,6 @@ get_id3v24_tags (const gchar          *data,
 				break;
 			default:
 				g_free (word);
-				g_warn_if_reached ();
 			}
 		}
 		}
@@ -1424,6 +1427,7 @@ get_id3v23_tags (const gchar          *data,
 
 			/* text frames */
 			word = id3v2_text_to_utf8 (data[pos], &data[pos + 1], csize - 1);
+
 			if (!tracker_is_empty_string (word)) {
 				g_strstrip (word);
 			}
@@ -1483,9 +1487,9 @@ get_id3v23_tags (const gchar          *data,
 				parts = g_strsplit (word, "/", 2);
 				if (parts[0]) {
 					tag->track_number = atoi (parts[0]);
-				}
-				if (parts[1]) {
-					tag->track_count = atoi (parts[1]);
+					if (parts[1]) {
+						tag->track_count = atoi (parts[1]);
+					}
 				}
 				g_strfreev (parts);
 				g_free (word);
@@ -1500,7 +1504,6 @@ get_id3v23_tags (const gchar          *data,
 				break;
 			default:
 				g_free (word);
-				g_warn_if_reached ();
 			}
 		}
 		}
@@ -1635,7 +1638,6 @@ get_id3v20_tags (const gchar          *data,
 				break;
 			default:
 				g_free (word);
-				g_warn_if_reached ();
 			}
 		}
 
@@ -1946,7 +1948,7 @@ extract_mp3 (const gchar          *uri,
 	audio_offset = parse_id3v2 (buffer, buffer_size, &md.id3v1, uri, metadata, &md);
 
 	md.title = tracker_coalesce (4, md.id3v24.title2, md.id3v23.title2, md.id3v22.title2, md.id3v1.title);
-	md.lyricist = tracker_coalesce (2, md.id3v24.text, md.id3v23.toly);
+	md.lyricist = tracker_coalesce (4, md.id3v24.text, md.id3v23.toly, md.id3v23.text, md.id3v22.text);
 
 	md.composer = tracker_coalesce (3,
 	                                md.id3v24.composer,
@@ -1970,7 +1972,6 @@ extract_mp3 (const gchar          *uri,
 	                                      md.id3v22.recording_time, md.id3v22.release_time,
 	                                      md.id3v1.recording_time);
 	md.publisher = tracker_coalesce (3, md.id3v24.publisher, md.id3v23.publisher, md.id3v22.publisher);
-	md.text = tracker_coalesce (3, md.id3v24.text, md.id3v23.text, md.id3v22.text);
 	md.copyright = tracker_coalesce (3, md.id3v24.copyright, md.id3v23.copyright, md.id3v22.copyright);
 	md.comment = tracker_coalesce (7,
 	                               md.id3v24.title3, md.id3v24.comment,
