@@ -161,7 +161,13 @@ get_fts_string (GStrv    search_words,
 	len = g_strv_length (search_words);
 
 	for (i = 0; i < len; i++) {
-		g_string_append (fts, search_words[i]);
+		gchar *escaped;
+
+		/* Properly escape the input string as it's going to be passed
+		 * in a sparql query */
+		escaped = tracker_sparql_escape (search_words[i]);
+
+		g_string_append (fts, escaped);
 
 		if (i < len - 1) {
 			if (use_or_operator) {
@@ -170,6 +176,8 @@ get_fts_string (GStrv    search_words,
 				g_string_append (fts, " ");
 			}
 		}
+
+		g_free (escaped);
 	}
 
 	return g_string_free (fts, FALSE);
@@ -976,18 +984,18 @@ get_all_by_search_foreach (gpointer value,
 		if (mime_type && mime_type[0] == '\0') {
 			mime_type = NULL;
 		}
-		
+
 		if (mime_type) {
 			g_print ("  %s\n"
 			         "    %s\n"
-			         "    %s\n", 
-			         urn, 
-			         mime_type, 
+			         "    %s\n",
+			         urn,
+			         mime_type,
 			         class);
 		} else {
 			g_print ("  %s\n"
-			         "    %s\n", 
-			         urn, 
+			         "    %s\n",
+			         urn,
 			         class);
 		}
 	}
@@ -1155,8 +1163,7 @@ main (int argc, char **argv)
 
 	if (terms) {
 		TrackerLanguage *language;
-		GHashTable *stop_words;
-		const gchar *stop_word_found;
+		gboolean stop_words_found;
 		gchar **p;
 
 		/* Check terms don't have additional quotes */
@@ -1172,36 +1179,30 @@ main (int argc, char **argv)
 			}
 		}
 
-		/* Check terms are not stopwords */
+		/* Check if terms are stopwords, and warn if so */
 		language = tracker_language_new (NULL);
-		stop_words = tracker_language_get_stop_words (language);
+		stop_words_found = FALSE;
+		for (p = terms; *p; p++) {
+			gchar *down;
 
-		for (p = terms, stop_word_found = NULL; *p && !stop_word_found; p++) {
-			gpointer data;
-			gchar *up = g_utf8_strdown (*p, -1);
+			down = g_utf8_strdown (*p, -1);
 
-			data = g_hash_table_lookup (stop_words, up);
-			if (data) {
-				stop_word_found = *p;
+			if (tracker_language_is_stop_word (language, down)) {
+				g_printerr (_("Search term '%s' is a stop word."),
+				            down);
+				g_printerr ("\n");
+
+				stop_words_found = TRUE;
 			}
-			g_free (up);
+
+			g_free (down);
 		}
 
-		if (stop_word_found) {
-			g_printerr (_("Search term '%s' is a stop word."),
-			            stop_word_found);
+		if (stop_words_found) {
+			g_printerr (_("Stop words are common words which "
+			              "may be ignored during the indexing "
+			              "process."));
 			g_printerr ("\n\n");
-			g_printerr (_("Stop words are common words which are "
-			              "ignored during the indexing process."));
-			g_printerr ("\n");
-			g_printerr (_("This means this search term will never "
-			              "be found when matching FTS entries."));
-			g_printerr ("\n\n");
-
-			g_option_context_free (context);
-			g_object_unref (language);
-
-			return EXIT_FAILURE;
 		}
 
 		g_object_unref (language);
